#
# spec file for package perl-DateTime-Format-Natural
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DateTime-Format-Natural
Name:           perl-DateTime-Format-Natural
Version:        1.180.0
Release:        2.3
%define cpan_version 1.18
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Parse informal natural language date/time strings
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SC/SCHUBIGER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Clone)
BuildRequires:  perl(DateTime)
BuildRequires:  perl(DateTime::HiRes)
BuildRequires:  perl(DateTime::TimeZone)
BuildRequires:  perl(List::MoreUtils)
BuildRequires:  perl(Module::Build) >= 0.42
BuildRequires:  perl(Module::Util)
BuildRequires:  perl(Params::Validate) >= 1.15
BuildRequires:  perl(Test::MockTime::HiRes)
BuildRequires:  perl(boolean)
Requires:       perl(Clone)
Requires:       perl(DateTime)
Requires:       perl(DateTime::HiRes)
Requires:       perl(DateTime::TimeZone)
Requires:       perl(List::MoreUtils)
Requires:       perl(Params::Validate) >= 1.15
Requires:       perl(boolean)
Provides:       perl(DateTime::Format::Natural) = 1.180.0
Provides:       perl(DateTime::Format::Natural::Calc) = 1.46
Provides:       perl(DateTime::Format::Natural::Compat) = 0.07
Provides:       perl(DateTime::Format::Natural::Duration) = 0.07
Provides:       perl(DateTime::Format::Natural::Duration::Checks) = 0.05
Provides:       perl(DateTime::Format::Natural::Expand) = 0.04
Provides:       perl(DateTime::Format::Natural::Extract) = 0.13
Provides:       perl(DateTime::Format::Natural::Formatted) = 0.12
Provides:       perl(DateTime::Format::Natural::Helpers) = 0.06
Provides:       perl(DateTime::Format::Natural::Lang::Base) = 1.08
Provides:       perl(DateTime::Format::Natural::Lang::EN) = 1.72
Provides:       perl(DateTime::Format::Natural::Rewrite) = 0.08
Provides:       perl(DateTime::Format::Natural::Test) = 0.130.0
Provides:       perl(DateTime::Format::Natural::Utils) = 0.08
Provides:       perl(DateTime::Format::Natural::Wrappers) = 0.03
%undefine       __perllib_provides
Recommends:     perl(Date::Calc)
%{perl_requires}

%description
'DateTime::Format::Natural' parses informal natural language date/time
strings. In addition, parsable date/time substrings may be extracted from
ordinary strings.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README TODO

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Oct  6 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.18
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.18  2023-10-05  <schubiger@cpan.org>
  - Merged development version to stable.
  1.17_02  2023-10-03  <schubiger@cpan.org>
  - Validate 'daytime' parameter.
  1.17_01  2023-10-01  <schubiger@cpan.org>
  - Minor wording tweak.
  - Minor indentation tweak.
* Wed Jun 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.17
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.17  2023-06-20  <schubiger@cpan.org>
  - Merged development version to stable.
  - Minor tweak.
  1.16_01  2023-06-18  <schubiger@cpan.org>
  - Fix parse_datetime_duration doesn't understand hours
    with no minutes, anymore. [github #19 - Giovanni Pensa]
* Sun Feb  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.16
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.16  2023-02-04  <schubiger@cpan.org>
  - Merged development version to stable.
  1.15_03  2023-02-03  <schubiger@cpan.org>
  - Drop generating compat Makefile.PL.
  1.15_02  2023-02-02  <schubiger@cpan.org>
  - Remove implicit m/d format; adjust tests.
    [github #11]
  1.15_01  2023-01-27  <schubiger@cpan.org>
  - Move further testing modules to test_requires.
    [inspired by github #10 - Karen Etheridge]
  1.15  2023-01-12  <schubiger@cpan.org>
  - Merged development version to stable.
  1.14_03  2023-01-10  <schubiger@cpan.org>
  - Minor whitespace tweak.
  1.14_02  2023-01-09  <schubiger@cpan.org>
  - Move testing modules to test_requires.
    [github #20 - Olaf Alders]
  - List Jim Avera in credits.
  1.14_01  2023-01-08  <schubiger@cpan.org>
  - Fix extract_datetime fails with newly-created parser.
    [rt #144219 - Jim Avera]
  1.14  2022-12-30  <schubiger@cpan.org>
  - Merged development version to stable.
  1.13_02  2022-12-29  <schubiger@cpan.org>
  - Distinguish between truncated/unaltered when testing.
  1.13_01  2022-08-06  <schubiger@cpan.org>
  - Add support for millisecond(s) as parsable unit.
* Mon Jan 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.13
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.13  2022-01-23  <schubiger@cpan.org>
  - Merged development version to stable.
  1.12_01  2022-01-20  <schubiger@cpan.org>
  - Fix demand_future not working for method count_weekday.
    [github #16 - joernclausen]
* Sat Mar 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.12
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.12  2021-03-19  <schubiger@cpan.org>
  - Merged development version to stable.
  1.11_03  2021-03-13  <schubiger@cpan.org>
  - Refactor extracting duration.
  - Don't try to trim the extract string twice.
  - Amend documentation of ::Utils.
  1.11_02  2020-10-16  <schubiger@cpan.org>
  - Introduce utility function trim().
  1.11_01  2020-10-03  <schubiger@cpan.org>
  - Assert that error() returns '' on success.
* Thu Sep 24 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.11
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.11  2020-09-23  <schubiger@cpan.org>
  - Merged development version to stable.
  1.10_04  2020-09-22  <schubiger@cpan.org>
  - Fail when parsing month/day with an explicit ymd-format.
  1.10_03  2020-09-19  <schubiger@cpan.org>
  - Clarify meaning of format option.
    [rt #133200 - Ricardo Signes]
  1.10_02  2020-09-05  <schubiger@cpan.org>
  - Allow mm/dd and dd/mm as valid formats and amend tests.
  - Improve format matching regexes.
  - List example with new format under examples section.
  1.10_01  2020-08-21  <schubiger@cpan.org>
  - Allow configuration to make "8/10" mean October 8.
    [rt #133140 - Ricardo Signes]
  - Minor tweaks.
* Sat Jun 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.10
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.10  2020-06-26  <schubiger@cpan.org>
  - Merged development version to stable.
  1.09_01  2020-06-21  <schubiger@cpan.org>
  - Support common unit abbreviations. [github #8 - grr]
* Mon May 18 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.09
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.09  2020-05-17  <schubiger@cpan.org>
  - Merged development version to stable.
  1.08_02  2020-05-01  <schubiger@cpan.org>
  - Require Params::Validate >=1.15 to fix test failures with
    older versions. [testers #112427415 - Alexandr Ciornii]
  1.08_01  2020-04-17  <schubiger@cpan.org>
  - Prefer the future even stronger with demand_future.
    [rt #92189 - Ricardo Signes]
  - When advancing to future times, consider also minutes/seconds.
* Sun Dec  8 2019 <timueller+perl@suse.de>
- updated to 1.08
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.08  2019-12-07  <schubiger@cpan.org>
  - Merged development version to stable.
  1.07_03  2019-12-06  <schubiger@cpan.org>
  - New supported formats: <count> seconds/minutes before/after
    yesterday/today/tomorrow. [github #6 - Felix Ostmann]
  1.07_02  2019-11-19  <schubiger@cpan.org>
  - New supported format: <count> hours before/after today.
    [github #6 - Felix Ostmann]
  1.07_01  2019-10-27  <schubiger@cpan.org>
  - New supported formats: <count> <unit> before/after
    noon/midnight. [github #6 - Felix Ostmann]
* Mon Apr  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.07
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.07  2019-03-29  <schubiger@cpan.org>
  - Merged development version to stable.
  1.06_01  2019-03-13  <schubiger@cpan.org>
  - New supported format: <variant> quarter. [Xiao Yafeng]
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.06
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.06  2018-10-28  <schubiger@cpan.org>
  - Merged development version to stable.
  1.05_02  2018-10-27  <schubiger@cpan.org>
  - Amend description of prefer_future option.
  - Include the time zone when constructing DateTime objects
    for the datetime option in dateparse.
  - Minor tweaks to dateparse.
  1.05_01  2018-10-25  <schubiger@cpan.org>
  - Fix advancing to future when both datetime and prefer_future
    options are provided.
* Mon Apr 24 2017 coolo@suse.com
- updated to 1.05
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.05  2017-04-23  <schubiger@cpan.org>
  - Merged development version to stable.
  1.04_01  2017-03-03  <schubiger@cpan.org>
  - New supported format: beginning/end of last month.
    [rt #120436 - Shawn M. Moore]
* Mon Jul 25 2016 coolo@suse.com
- updated to 1.04
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.04  2016-07-24  <schubiger@cpan.org>
  - Merged development version to stable.
  1.03_02  2016-07-15  <schubiger@cpan.org>
  - Document format: ISO 8601 <date>T<time>.
  - Amend introduction text for examples section.
  - List Ricardo Signes in credits.
  1.03_01  2016-07-09  <schubiger@cpan.org>
  - New supported format: ISO 8601 <date>T<time>.
    [rt #115737 - Ricardo Signes]
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.03
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.03  2015-08-02  <schubiger@cpan.org>
  - Merged development version to stable.
  1.02_03  2015-07-21  <schubiger@cpan.org>
  - Suggestions for simple documentation improvements.
    [rt #98634 - Tim Bunce]
  1.02_02  2015-06-05  <schubiger@cpan.org>
  - Add encoding directive to POD. [rt #105000 - Debian Perl Group]
  1.02_01  2014-02-09  <schubiger@cpan.org>
  - Add metadata repository link. [David Steinbrunner]
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.02
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  1.02  2013-04-30  <schubiger@cpan.org>
  - Merged development version to stable.
  1.01_05  2013-04-01  <schubiger@cpan.org>
  - Parse and extract relative durations in reversed order.
  - Document reversed relative durations under examples.
  - Treat for <count> <unit> grammar expressions as durations.
  - Refine gathering idents for from <count> to <count> durations.
  - Use rightmost matching token on left side of duration as type.
  - Split duration string only if accompanied by whitespace.
  - Strengthen matching duration substrings against regexes.
  - Extract regex captured punctuation marks in loop body.
  - Undo some loop indentation in test files.
  - Reorder version number variable in Calc class.
  1.01_04  2013-01-17  <schubiger@cpan.org>
  - Concatenate duration expression chunks with separator.
  - Merge calls for extracting duration expressions.
  - Distinguish between expression types when finalizing.
  - Simplify finalizing date/grammar duration expressions.
  - Test that expressions do not overlap with duration ones.
  - Strip timespan separators from extract string.
  - Normalize whitespace of duration expressions.
  - Keep duration extract methods private.
  - Don't declare a plan for extract-expression tests.
  - Enhance comment in extract-expression test file.
  1.01_03  2012-12-06  <schubiger@cpan.org>
  - Fix fatal error from extract tests on 5.{8.9,10.0}.
  - Display extracted strings for dateparse.
  1.01_02  2012-11-29  <schubiger@cpan.org>
  - Extract relative and rewritten duration expressions.
  - Check parsing of extracted expressions.
  1.01_01  2012-10-25  <schubiger@cpan.org>
  - Narrow scope of variables in _extract_expressions().
  - Improve finalizing duration expressions.
  1.01  2012-09-07  <schubiger@cpan.org>
  - Merged development version to stable.
  1.00_02  2012-09-01  <schubiger@cpan.org>
  - Duplicate and extend types only for grammar expansion.
  - Initialize subscript variable.
  - Remove trailing semicolon in do block.
  1.00_01  2012-07-21  <schubiger@cpan.org>
  - Extract expanded expressions and add a test.
  1.00  2012-05-30  <schubiger@cpan.org>
  - Merged development version to stable.
  - Replace use of constant pragma with boolean.
  0.99_01  2012-05-20  <schubiger@cpan.org>
  - Introduce ::Expand which handles expanding grammar.
  - Enhance main grammar loop to enable grammar expansion.
  - Include count of tokens for expanded grammar in lookup map.
  - Add test file for expansions.
  - Make the truncate_to grammar option an array reference.
  - Truncate values after each worker method called.
  - Move truncating code to a separate method.
  - Require Clone as prerequisite.
  - Mention expansion of grammar in docs.
  0.99  2012-04-26  <schubiger@cpan.org>
  - Merged development version to stable.
  0.98_03  2012-04-22  <schubiger@cpan.org>
  - Check if daytime exists in _daytime_variant().
  - Load modules in test files where missing.
  0.98_02  2012-04-22  <schubiger@cpan.org>
  - Add validation rules to allow passing DateTime::TimeZone
    objects. [Roman Filippov]
  - Test providing a DateTime::TimeZone object.
  - Load DateTime::TimeZone explicitly.
  - Test validation of constructor arguments.
  - List Roman Filippov in credits.
  0.98_01  2012-01-01  <schubiger@cpan.org>
  - Mention and link to dateparse in the See also section.
  0.98  2011-10-29  <schubiger@cpan.org>
  - Merged development version to stable.
  0.97_02  2011-10-27  <schubiger@cpan.org>
  - Strip leading and trailing spaces from input strings.
  0.97_01  2011-10-25  <schubiger@cpan.org>
  - Support parsing timestamp. [Xiao Yafeng]
  0.97  2011-08-17  <schubiger@cpan.org>
  - Merged development version to stable.
  0.96_04  2011-08-16  <schubiger@cpan.org>
  - Check that the datetime string for dateparse has at most
    two chunks (date/time); also require DateTime.
  - Elaborate on the format of dateparse's datetime string.
  0.96_03  2011-08-13  <schubiger@cpan.org>
  - Add the datetime switch to dateparse and document it.
  - Print dateparse's dates formatted according to ISO 8601.
  0.96_02  2011-08-10  <schubiger@cpan.org>
  - Revert truncating of <count> <unit> ago formats.
  - Add Xiao Yafeng to credits.
  0.96_01  2011-08-01  <schubiger@cpan.org>
  - New supported format: today <count> <unit> ago. [Xiao Yafeng]
  - Truncate for this and other ago formats to day if there is
    no time component in order to produce more consistent results.
  - Add new and adjust existing regular tests for these formats;
    moreover, complete the list of parse failure tests.
  - List the added grammar in the documentation.
  0.96  2011-06-01  <schubiger@cpan.org>
  - Merged development version to stable.
  0.95_03  2011-05-30  <schubiger@cpan.org>
  - Add the extract switch to dateparse and document it.
  - Change dateparse's prefer_future option to be not negatable.
  0.95_02  2011-05-28  <schubiger@cpan.org>
  - Reorder the nested extract loop iterating through the grammar
    entries to process only one subentry for all matching tokens.
  - Move the check for a date when extracting expressions to a method.
  - Add assert tests for extract_datetime(): one for the context
    dependant return and another for the nested extract loop fix.
  - Improve code visually of the parse success and failure test files.
  0.95_01  2011-05-19  <schubiger@cpan.org>
  - Do no longer recommend Test::Pod and Test::Pod::Coverage.
  - Use quantifier which matches 1 or more times when extracting
    subroutine or method names.
  - Assign a list instead of pushing a string for time entries.
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.98
  see /usr/share/doc/packages/perl-DateTime-Format-Natural/Changes
  0.98  2011-10-29  <schubiger@cpan.org>
  - Merged development version to stable.
  0.97_02  2011-10-27  <schubiger@cpan.org>
  - Strip leading and trailing spaces from input strings.
  0.97_01  2011-10-25  <schubiger@cpan.org>
  - Support parsing timestamp. [Xiao Yafeng]
  0.97  2011-08-17  <schubiger@cpan.org>
  - Merged development version to stable.
  0.96_04  2011-08-16  <schubiger@cpan.org>
  - Check that the datetime string for dateparse has at most
    two chunks (date/time); also require DateTime.
  - Elaborate on the format of dateparse's datetime string.
  0.96_03  2011-08-13  <schubiger@cpan.org>
  - Add the datetime switch to dateparse and document it.
  - Print dateparse's dates formatted according to ISO 8601.
  0.96_02  2011-08-10  <schubiger@cpan.org>
  - Revert truncating of <count> <unit> ago formats.
  - Add Xiao Yafeng to credits.
  0.96_01  2011-08-01  <schubiger@cpan.org>
  - New supported format: today <count> <unit> ago. [Xiao Yafeng]
  - Truncate for this and other ago formats to day if there is
    no time component in order to produce more consistent results.
  - Add new and adjust existing regular tests for these formats;
    moreover, complete the list of parse failure tests.
  - List the added grammar in the documentation.
  0.96  2011-06-01  <schubiger@cpan.org>
  - Merged development version to stable.
  0.95_03  2011-05-30  <schubiger@cpan.org>
  - Add the extract switch to dateparse and document it.
  - Change dateparse's prefer_future option to be not negatable.
  0.95_02  2011-05-28  <schubiger@cpan.org>
  - Reorder the nested extract loop iterating through the grammar
    entries to process only one subentry for all matching tokens.
  - Move the check for a date when extracting expressions to a method.
  - Add assert tests for extract_datetime(): one for the context
    dependant return and another for the nested extract loop fix.
  - Improve code visually of the parse success and failure test files.
  0.95_01  2011-05-19  <schubiger@cpan.org>
  - Do no longer recommend Test::Pod and Test::Pod::Coverage.
  - Use quantifier which matches 1 or more times when extracting
    subroutine or method names.
  - Assign a list instead of pushing a string for time entries.
* Tue May 17 2011 pascal.bleser@opensuse.org
- update to 0.95:
  * new supported format: <monthday> <month> <year> <time am/pm> [RT#67780]
  * conditionally rewrite date strings, currently ones with an 'at' followed
    by a time or daytime (e.g., noon)
  * parse times with AM/PM at word boundary separated by a space (through
    removing the space before parsing) [RT#67561]
  * parse and document formatted dates with an abbreviated month name in the
    middle [RT#67395]
  * remove commas from date string now before rewriting aliases
  * set month and implicit day explicitly to avoid overlap parse failures
  * keep the minute or higher precision requirement when extracting one token
    time expressions, but undo the grammar change
  * introduce a class to extract parsable expressions from strings
  * add and document the extract_datetime() method
  * require precision in hour or higher for one token time expressions,
    otherwise extracting expressions would be impeded
  * new supported format: <month> <monthday>, <year> <time am/pm> [RT#65072]
  * allow for time regexes to match times with precision in seconds
  * conditionally truncate to units and remove unit assignments of zero
  * new supported format: <weekday> <daytime> [RT#63438]
  * new supported format: <year> <month> <monthday> [RT#63429]
  * don't parse ambiguous <time>, <monthday> and <month> expressions
  * new supported formats: <time> <month> <monthday> and <time> AM/PM <month>
    <monthday> [RT#62164]
  * add support for the <time am/pm> <month> <monthday> format
  * new supported formats: <monthday> <month> <time>, <monthday> <month>
    <time> AM/PM and <month> <monthday> <time> AM/PM [RT#62164]
  * add support for the <monthday> <month> <time am/pm> format
  * new supported formats: <variant> <weekday> <time> AM/PM and <time> AM/PM
    <variant> <weekday> [RT#62164]
  * add support for the <variant> <weekday> <time am/pm> format
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Aug 22 2010 pascal.bleser@opensuse.org
- initial package (0.89)
